Improve this doc

# Error: $parse:isecobj
Referencing Object Disallowed

    Referencing Object in Angular expressions is disallowed! Expression: {0}

## Description

Occurs when an expression attempts to access the 'Object' object (Root object in JavaScript).

Angular bans access to Object from within expressions since access is a known way to modify the behaviour of existing objects.

To resolve this error, avoid Object access.